--  _____________________________________________________________
--
--  HitsMode
--
--  by Allara
--
--  modifications by Elieehel (EU-Aszune)
--  _____________________________________________________________        
--
--  Please see HitsMode-Readme.txt for details!
--  _____________________________________________________________
--
--  Special thanks to these people for their code examples:
--
--    DmgInc for the brilliantly simple parsing in CombatStats
--    Grayhoof for the options window and logic in Scrolling Combat Text
--    Sudo/Suds for the basic combat parsing in DPSPLUS
--    AlexanderYoshi for the options implementation in Cosmos
--    NCSoft for the graphical theme this UI is loosely based on
--
--    And ALL THE USERS for their bug reports, feature requests,
--    and support!
--  _____________________________________________________________
--
--  Contact me at allara.starmist@gmail.com
--  _____________________________________________________________



-- Current version
HM_Version = "2.4";

-- Global state variables
HMPlayer = nil;
HM_NameRegistered = 0;
HM_Enabled = 0;
HM_CoerceChat = 0;
HM_CoerceChat_CurrentWindow = 0;
HM_OptionsVisible = 0;
HM_CurrentPanel = 1;
HM_DrawDataStarted = 0;
HM_POptions = nil;
HM_CurrentColor = 0;
HM_NUMTABS = 2;
HM_StandardEvents = {
        "UNIT_NAME_UPDATE",
        "PLAYER_ENTERING_WORLD",
        "CHAT_MSG_COMBAT_CREATURE_VS_SELF_MISSES",
        "CHAT_MSG_COMBAT_CREATURE_VS_SELF_HITS",
        "CHAT_MSG_SPELL_PERIODIC_HOSTILEPLAYER_DAMAGE",
        "CHAT_MSG_COMBAT_XP_GAIN",
        "CHAT_MSG_COMBAT_SELF_HITS",
        "CHAT_MSG_SPELL_SELF_DAMAGE",
        "CHAT_MSG_COMBAT_PET_HITS",
        "CHAT_MSG_SPELL_PET_DAMAGE",
        "CHAT_MSG_SPELL_PERIODIC_CREATURE_DAMAGE",
        "CHAT_MSG_COMBAT_SELF_MISSES",
        "CHAT_MSG_COMBAT_PET_MISSES",
        "CHAT_MSG_COMBAT_HOSTILE_DEATH",
        "CHAT_MSG_SPELL_AURA_GONE_SELF",
        "CHAT_MSG_SPELL_AURA_GONE_OTHER",
        "CHAT_MSG_SPELL_PERIODIC_SELF_BUFFS",
        "CHAT_MSG_SPELL_HOSTILEPLAYER_BUFF",
        "CHAT_MSG_SPELL_PERIODIC_HOSTILEPLAYER_BUFFS",
        "CHAT_MSG_COMBAT_HOSTILEPLAYER_MISSES",
        "CHAT_MSG_COMBAT_HOSTILEPLAYER_HITS",
        "CHAT_MSG_SPELL_ITEM_ENCHANTMENTS",
        "CHAT_MSG_SPELL_PERIODIC_SELF_DAMAGE",
        "CHAT_MSG_SPELL_SELF_BUFF",
        "CHAT_MSG_SPELL_HOSTILEPLAYER_DAMAGE",
        "CHAT_MSG_SPELL_CREATURE_VS_SELF_DAMAGE",
        "CHAT_MSG_SPELL_PERIODIC_CREATURE_BUFFS",
        "CHAT_MSG_SPELL_TRADESKILLS",
        "CHAT_MSG_COMBAT_MISC_INFO",
        "CHAT_MSG_LOOT",
        "UPDATE_FACTION",
        "CHAT_MSG_COMBAT_FACTION_CHANGE",
        "CHAT_MSG_SPELL_BREAK_AURA",
        "SPELLCAST_INTERRUPTED",
        "CHAT_MSG_SPELL_PERIODIC_FRIENDLYPLAYER_BUFFS",
        "CHAT_MSG_SPELL_PERIODIC_PARTY_BUFFS",
        "CHAT_MSG_COMBAT_HONOR_GAIN",
};
HM_DebugEvents = HM_StandardEvents;


function HM_OnLoad()
        -- Activates all the text used by HitsMode, in the proper language
        HitsMode_Localize();

        -- Register events
        for key, value in pairs(HM_StandardEvents) do
                this:RegisterEvent(value);
        end

        -- Add Slash Commands
        SlashCmdList["HITSMODEOPTIONS"] = HM_ShowOptions;
        SLASH_HITSMODEOPTIONS1 = "/hitsmode";
        SLASH_HITSMODEOPTIONS2 = "/hm";
        SlashCmdList["HITSMODEDEBUG"] = HM_DebugModeToggle;
        SLASH_HITSMODEDEBUG1 = "/hmdebug";
        
        -- Add extra font heights to the game
        table.insert(CHAT_FONT_HEIGHTS, 24);
        table.insert(CHAT_FONT_HEIGHTS, 36);
        table.insert(CHAT_FONT_HEIGHTS, 48);
        table.insert(CHAT_FONT_HEIGHTS, 72);
        table.insert(CHAT_FONT_HEIGHTS, 96);
end


-- Adds a message to the 3-line error queue
function HM_DisplayOverheadText(msg)
        UIErrorsFrame:AddMessage(msg, 1.0, 1.0, 1.0, 1.0, UIERRORS_HOLD_TIME);
end


-- Adds a message to the default chat window
function HM_Print(msg)
        if (DEFAULT_CHAT_FRAME) then
                DEFAULT_CHAT_FRAME:AddMessage(msg);
        end
end


-- Adds a message to the current HitsMode window
function HM_HMPrint(msg)
        local c = HM_CoerceChat;
        HM_CoerceChat = 0;        -- turn off coerce so we make sure to get the right chat window during GetValue
        if (HM_CoerceChat_CurrentWindow == 0 or HM_CoerceChat_CurrentWindow == nil) then return; end
        getglobal("ChatFrame"..HM_GetValue("window"..HM_CoerceChat_CurrentWindow)):AddMessage(msg);
        HM_CoerceChat = c;        -- set coerce back where it was
end


-- BuildColorCode:
-- Returns a string that changes the color in any WoW displayed string.
-- You can use |r to close the color change or just change to the next color.
function HM_BCC(r, g, b)
        return string.format("|cff%02x%02x%02x", (r*255), (g*255), (b*255));
end


-- Toggle debug mode
function HM_DebugModeToggle()
        if (HM_GetValue("debug") == 1) then
                HM_SetAllValues("debug", 0);
                HM_Print("HitsMode: Debug mode OFF. You must reload your UI for the changes to take effect.");
        else
                HM_SetAllValues("debug", 1);
                HM_Print("HitsMode: Debug mode ON. You must reload your UI for the changes to take effect.");
        end
end


-- Displays the options window
function HM_ShowOptions()
        ShowUIPanel(HMOptions);
end


-- Hides the options window
function HM_HideOptions()
        HideUIPanel(HMOptions);
end


-- Toggles the options window
function HM_ToggleOptions()
        if (HM_OptionsVisible == 1) then
                HM_HideOptions();
        else
                HM_ShowOptions();
        end
end


-- Do all of our initialization
function HM_Initialize()
        -- Turn off the initialize events
        this:UnregisterEvent("UNIT_NAME_UPDATE");
        this:UnregisterEvent("PLAYER_ENTERING_WORLD");

        -- Startup the options window
        HM_CreateOptionsWindowLines();
                
        -- Startup the options system
        HM_InitializeOptionsSystem();
        
        -- Register debug events if necessary
        if (HM_GetValue("debug") == 1) then
                for key, value in pairs(HM_DebugEvents) do
                        this:RegisterEvent(value);
                end
                HM_Print(HM_BCC(.3, .3, 1).."HitsMode: Debug mode is ON.");
        end
        
        -- Turn HitsMode on if it's enabled
        if (HM_GetValue("enable") ~= 0) then
                HM_Enable();
        end

        -- Initialize the options window
        PanelTemplates_SetNumTabs(HMOptionsPaneBgFrame, HM_NUMTABS);
        HM_SwitchPanel(1);

        -- Print our loaded message
        HM_Print(HM_BCC(.3, .3, 1).."Welcome to HitsMode"..HM_BCC(1, 1, 1).." v"..HM_Version..HM_BCC(.3, .3, 1).." by Allara with modifications by Elieehel. Type /hitsmode or /hm for options.");
end


-- GetColorCode: Gets the configured color and converts it to a chat color code 
function HM_GCC(option)
        local color = HM_GetColor(option);
        if (color.r == nil or color.g == nil or color.b == nil) then
                HM_Print("HM_GetColorCode: Badly configured color: "..option);
                return HM_BCC(0,0,0);
        end
        return HM_BCC(color.r, color.g, color.b);
end


-- Gets a configured chat color code and scales it by a certain value
function HM_GetScaledColorCode(option, scale)
        local color = HM_GetColor(option);
        if (color.r == nil or color.g == nil or color.b == nil) then
                HM_Print("HM_GetScaledColorCode: Badly configured color: "..option);
                return HM_BCC(0,0,0);
        end
        color.r = (color.r * scale);
        color.g = (color.g * scale);
        color.b = (color.b * scale);
        local string = HM_BCC(color.r, color.g, color.b);
        return string;
end


-- GetColorCodeOverlay:
-- Gets an overlayed chat color code. Requires some extra input, where:
--   unit is either you, pet, or mob
--   msgtype is crit or anything else
-- Crit overlay takes precedence; a Pet Crit will appear with Crit overlay only.
function HM_GCCO(option, unit, msgtype)
        local color = HM_GetColor(option);
        
        if (msgtype == "crit") then
                if (HM_GetValue("critoverlay") == 1) then
                        local color2 = HM_GetColor("critoverlay");
                        color.r = (color.r/2) + (color2.r/2);
                        color.g = (color.g/2) + (color2.g/2);
                        color.b = (color.b/2) + (color2.b/2);
                end
        elseif (unit == "pet") then
                if (HM_GetValue("petoverlay") == 1) then
                        local color2 = HM_GetColor("petoverlay");
                        color.r = (color.r/2) + (color2.r/2);
                        color.g = (color.g/2) + (color2.g/2);
                        color.b = (color.b/2) + (color2.b/2);
                end
        end
        
        return HM_BCC(color.r, color.g, color.b);
end


-- Gets the requested chat message string. This does the checking for capitalize.
function HM_GetString(option)
        local s;

        if (HM_ChatMessages[option] == nil) then
                HM_Print("HM_GetString: not found "..option);
                return " ";
        end
        s = HM_ChatMessages[option];
        if (HM_GetValue("caps") == 1 and option ~= "FOR") then
                s = string.upper(string.sub(s, 1, 1))..string.sub(s, 2);
        end
        return s;
end


-- Returns brackets if they have been turned on
function HM_BracketLeft()
        if (HM_GetValue("brackets") == 1) then
                return HM_GCC("brackets")..HM_GetString("BRACKETLEFT").."|r";
        else
                return "";
        end
end


function HM_BracketRight()
        if (HM_GetValue("brackets") == 1) then
                return HM_GCC("brackets")..HM_GetString("BRACKETRIGHT").."|r";
        else
                return "";
        end
end


-- Returns non-nil if s is the player's pet
function HM_IsPet(s)
        if ((s == UnitName("pet")) or (string.upper(s) == "YOUR PET")) then
                return true;
        else
                return nil;
        end
end

function HM_IsTarget(s)
        if(UnitIsUnit(s, "target")) then
                return 1;
        else
                return 0;
        end
end

function HM_Enable()
        local c;
        
        if (HM_Enabled == 0) then
                HM_CoerceChat = 0;
                for c = 1, 4 do
                        if (HM_GetValue("enable"..c) == 1) then
                                HM_CoerceChat_CurrentWindow = c;
                                HM_Enable_Multiwindow(c);
                        end
                end
                HM_Enabled = 1;
        end
end


function HM_Enable_Multiwindow(window)
        local shown, chatFrame, chatTab, _;
        local i = HM_GetValue("window"..window);
                
        _, _, _, _, _, _, shown, _ = GetChatWindowInfo(i);
        chatFrame = getglobal("ChatFrame"..i);
        chatTab = getglobal("ChatFrame"..i.."Tab");
        if (not shown and not chatFrame.isDocked and (i ~= 1)) then
                FCF_SetWindowName(chatFrame, "HitsMode "..window);
                FCF_SetWindowColor(chatFrame, DEFAULT_CHATFRAME_COLOR.r, DEFAULT_CHATFRAME_COLOR.g, DEFAULT_CHATFRAME_COLOR.b);
                FCF_SetWindowAlpha(chatFrame, DEFAULT_CHATFRAME_ALPHA);
                SetChatWindowLocked(i, nil);
                ChatFrame_RemoveAllMessageGroups(chatFrame);
                chatFrame:Show();
                --chatTab:Show();
                SetChatWindowShown(i, 1);
                FCF_DockFrame(chatFrame, i);
        end
        if (HM_GetValue("removescroll", window) == 1) then
                local prefix = "ChatFrame"..i;
                if (getglobal(prefix.."BottomButton")) then
                        getglobal(prefix.."BottomButton"):Hide();
                end
                if (getglobal(prefix.."UpButton")) then
                        getglobal(prefix.."UpButton"):Hide();
                end
                if (getglobal(prefix.."DownButton")) then
                        getglobal(prefix.."DownButton"):Hide();
                end
        end
        if (HM_GetValue("resize", window) == 1 and i ~= 1) then
                chatFrame:SetMaxResize(1000, 700);
                chatFrame:SetMinResize(40, 40);
        else
                chatFrame:SetMaxResize(608, 400);
                chatFrame:SetMinResize(296, 75);
        end
        HM_HMPrint("HM window "..window.." is here!");
end


function HM_Disable()   -- Won't disable if we're already disabled
        if (HM_Enabled == 1) then
                HM_Enabled = 0;
        end
end


-- Main event handler
function HM_OnEvent()
        -- Player loaded completely, time to load us
        if (event == "UNIT_NAME_UPDATE" and arg1 == "player") or (event=="PLAYER_ENTERING_WORLD") then
                if (HM_NameRegistered == 1) then
                        return;
                end
                local playerName = UnitName("player");
                if (playerName ~= UNKNOWNBEING and playerName ~= "Unknown Entity" and playerName ~= nil ) then
                        HM_NameRegistered = 1;
                        HM_Initialize();
                end
        end
        
        if (HM_Enabled == 1) then
                HM_Parse(event, arg1);
        end
end
