-- HitsMode, by Allara


--
--  HitsMode User Interface Code and Graphics Copyright (C) 2005-2007 Jeremy Fuller (Allara)
--      
--  Please do not use the code or graphics for the user interface without permission.
--  Contact me at allara.starmist@gmail.com for more information.
--


HM_NUMPANELS = 4;
HM_OptionsList = { };


-- Creates the HM_OptionsList object. This needs to be called as soon as possible during init.
function HM_CreateOptionsWindowLines()
        local p, i;

        -- Create the initial object
        HM_OptionsList = { };
        
        -- Create the panels
        for p = 1, HM_NUMPANELS do
                HM_OptionsList[p] = { };
        end
        
        -- Initialize the iterators
        p = 1;
        i = 1;
        
        
        
        -- Now we iterate manually through the options. We only set values that are needed. The
        -- Draw loop looks for non-present (nil) options rather than an explicit true/false
        -- value. This allows us to write the configs quicker and to save memory. We also
        -- specify default values here, rather than elsewhere. HM_LoadDefaultOptions goes through
        -- this data to create it's default setup. Presets are handled differently; they
        -- explicitly go through and set each option using a preset function. I could have just
        -- used a Preset to generate the initial defaults, but I'd rather have atomic data here
        -- to prevent errors down the line. Plus it's a lot easier to specify a default during
        -- the design stage of the options list.
        --
        -- The Draw function is very nil-friendly. The only thing you HAVE to have is "text". An
        -- empty Pane is okay... nothing will be displayed.
        --
        -- The options are:
        --    text            The text [required]
        --    type                                                The type of option
        --      "heading"                        A heading - only specify text
        --      "slider"      A slider
        --      nil           A regular option (defaults to 4 checkboxes and color swatch)
        --    single          If present, only shows checkbox number 4, uses SetAllValues to save
        --    hideColor       If present, hides the color swatch
        --    minValue        For sliders, the minimum value
        --    maxValue        For sliders, the maximum value
        --    minText         For sliders, the minimum text
        --    maxText         For sliders, the maximum text
        --    valueStep       For sliders, the step value
        --    var                                                        A string: the variable used to save this option
        --    default         The default value for the variable; type doesn't matter
        --                defaultColor.                The default color for the option
        --      r, g, b
        --    default1-4                        The default toggle for each separate chat window
        --    toolTip         Info for the option. Word-wrapped, can hold 4 lines or about 360 chars.
        
        
        
        ----------------------------------------------------------------------------------------
        ---- PANE 1: General Options -----------------------------------------------------------
        ----------------------------------------------------------------------------------------
        HM_OptionsList[p][i] = { ---------------------------------------------------------------
                type = "heading",
                text = "General",
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Enable HitsMode",
                single = true,
                hideColor = true,
                var = "enable",
                default = 1,
                toolTip = "Enables or disables HitsMode as a whole.\nDisabling HitsMode will not close any chat windows.\nGo to the Windows tab and scroll down to enable/disable each individual chat window.",
        };
        i = i + 1;
        HM_OptionsList[p][i] = { ---------------------------------------------------------------
                type = "heading",
                text = "Global Chat Window Options",
                toolTip = "These options let you choose how the chat should be displayed. \nUse the four checkboxes to choose the option for each chat window separately.",
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Enable Verbose Mode A",
                var = "verbosea",
                defaultColor = { r = (255/255),  g = (255/255),  b = (255/255) },                -- White
                toolTip = "Shows more information in chat. Mode A looks like:\n[You] hit for 12\n[Wolf] hits for 8",
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Enable Verbose Mode B",
                var = "verboseb",
                default1 = 1,
                defaultColor = { r = (255/255),  g = (255/255),  b = (255/255) },                -- White
                toolTip = "Shows more information in chat. Mode B looks like:\n[You] hit [Wolf] for 12\n[Wolf] hits [You] for 8",
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Enable Verbose Mode C",
                var = "verbosec",
                defaultColor = { r = (255/255),  g = (255/255),  b = (255/255) },                -- White
                toolTip = "Shows more information in chat. Mode C looks like:\n12 - [You] hit [Wolf]\n8 - [Wolf] hits [You]",
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Short Verbose Mode",
                hideColor = true,
                var = "shortmode",
                toolTip = "Eliminates the \"for\" in most messages.",
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Show Skill Names",
                var = "showskill",
                default1 = 1,
                defaultColor = { r = (202/255),  g = (76/255),  b = (217/255) },                -- Dark Pink
                toolTip = "Shows the name of the skill or spell that was used. \nThis only works if you have one of the Verbose Modes turned on.",
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Capitalize Text",
                hideColor = true,
                var = "caps",
                toolTip = "Capitalizes the beginning of some verbose mode text.",
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Show Brackets",
                var = "brackets",
                default1 = 1,
                defaultColor = { r = (255/255),  g = (255/255),  b = (255/255) },                -- White
                toolTip = "Check to display brackets around unit names.",
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Show Your Name",
                var = "showyou",
                default1 = 1,
                defaultColor = { r = (  0/255),  g = (192/255),  b = (255/255) },                -- Light Blue
                toolTip = "Shows the unit name for events caused by you. \nUnit names are only shown when Verbose Mode is on.",
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Show Pet's Name",
                var = "showpet",
                default1 = 1,
                defaultColor = { b =  0.388235 , g =         1,  r =  0.376471 },                -- Light Green
                toolTip = "Shows the unit name for events caused by your pet. \nUnit names are only shown when Verbose Mode is on.",
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Show Attacker's Name",
                var = "showmob",
                default1 = 1,
                defaultColor = { b =  0.427451,  g =  0.454902,  r =         1 },                -- Light Pink
                toolTip = "Shows the unit name for events caused by your attacker.\n Unit names are only shown when Verbose Mode is on.",
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Flag Crits",
                var = "flagcrits",
                default1 = 1,
                defaultColor = { r = (255/255),  g = (255/255),  b = (  0/255) },                -- Yellow
                toolTip = "Puts a flag around all critical events. Looks like:\n*1297*",
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Flag Heals",
                var = "flagheals",
                hideColor = true,
                default1 = 1,
                toolTip = "Puts a plus sign in front of heals. Looks like:\n+892",
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Flag Pet Damage",
                var = "flagpet",
                hideColor = true,
                default1 = 1,
                toolTip = "Puts a flag around all pet events. Looks like:\n~36~",
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Recolor Crits",
                var = "critoverlay",
                defaultColor = { r = (255/255),  g = (255/255),  b = (255/255) },                -- White
                toolTip = "Overlays the selected color over crits of all types. \nFor example, white would make all crits appear brighter. A pet crit \nwill not be double overlayed (it will use the pet overlay).",
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Recolor Pet Damage",
                var = "petoverlay",
                defaultColor = { r = (255/255),  g = (255/255),  b = (255/255) },                -- White
                toolTip = "Overlays the selected color over all pet numeric messages. \nFor example, white would make all pet damage appear \nbrighter. A pet crit will not be double overlayed (it will use the pet overlay).",
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                text = "Recolor For Magic Schools",
                hideColor = true,
                var = "schoCol",
                default1 = 1,
                toolTip = "Overlays the selected color over all spell damage numeric messages. \nFrost damage will be colored blue, fire damage will be colored red, etc.",
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                text = "Extra Values",
                var = "extval",
                default1 = 1,
                defaultColor = { r = (172/255),  g = (172/255),  b = (172/255) },                -- grayish
                toolTip = "Defines whether resisted, absorbed and blocked values should be \nshown after spelldamage or not.",
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Show Rested Experience",
                var = "showrested",
                hideColor = true,
                single = true,
                default1 = 1,
                toolTip = "Shows how much experience was rested experience, if any. \nLooks like: 470 (+235)",
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                text = "Show Reputation Gains",
                var = "you_gain_rep",
                default1 = 1,
                defaultColor = { r = (255/255),  g = (128/255),  b = (128/255) },                -- Pink
                toolTip = "Shows with which faction, when and how much reputation you gain.",
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Remove Scroll Buttons",
                var = "removescroll",
                hideColor = true,
                toolTip = "Lets you selectively remove the scroll buttons \nfrom any of the four HitsMode chat windows. \n(This will only work on windows that are enabled.) \n\nIf the buttons reappear for some reason (this does happen), \nopen and close the HitsMode options window to fix it.",
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Allow Greater Resizing for Chat Windows",
                var = "resize",
                hideColor = true,
                toolTip = "This will allow the selected chat windows to be resized smaller \nand larger than the World of Warcraft defaults. \nYou cannot do this with the General Chat window (window 1). \n"..HM_BCC(1,.2,.2).."WARNING: This has been known to cause a crash when \nused with other chat-related add-ons. \nIf WoW crashes after you turn this on, leave it off.",
        };
        i = i + 1;        
        HM_OptionsList[p][i] = { ---------------------------------------------------------------
                type = "heading",
                text = "Window 1 Options",
                toolTip = "These options are specific to chat window 1 only. \nThis is where you specify which WoW chat window to \nuse for each HitsMode window. \n(More options are planned for future versions.)",
        };
        i = i + 1;        
        HM_OptionsList[p][i] = { 
                text = "Enable Chat Window 1",
                var = "enable1",
                hideColor = true,
                single = true,
                default = 1,
                toolTip = "The master switch that turns on and off chat window 1.",
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                text = "Output to Chat Window",
                type = "slider",
                var = "window1",
                minValue = 1,
                maxValue = 7,
                minText = "1",
                maxText = "7",
                valueStep = 1,
                default = 7,
                default1 = 7,
                default2 = 7,
                default3 = 7,
                default4 = 7,
                toolTip = "Selects which chat window HitsMode outputs to. \nThere can be up to 7 chat windows open at once. \nGeneral Chat is usually 1, and Combat Chat is usually 2. \nMove this slider until you find the one you want to use.",
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                text = "Message Threshold",
                type = "slider",
                var = "threshold1",
                minValue = 0,
                maxValue = 200,
                minText = "0",
                maxText = "200",
                valueStep = 1,
                default = 0,
                default1 = 0,
                default2 = 0,
                default3 = 0,
                default4 = 0,
                toolTip = "Lets you suppress messages with values below a certain threshold.\nFor example, setting this slider to 10 will suppress all messages that are 10 points or less.\nThe threshold functions as an absolute value, so the above example would\nsuppress messages between -10 and 10.",
        };
        i = i + 1;        
        HM_OptionsList[p][i] = { ---------------------------------------------------------------
                type = "heading",
                text = "Window 2 Options",
                toolTip = "These options are specific to chat window 2 only. \nThis is where you specify which WoW chat window to \nuse for each HitsMode window. (More options are planned for future versions.)",
        };
        i = i + 1;        
        HM_OptionsList[p][i] = { 
                text = "Enable Chat Window 2",
                var = "enable2",
                hideColor = true,
                single = true,
                toolTip = "The master switch that turns on and off chat window 2.",
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                text = "Output to Chat Window",
                type = "slider",
                var = "window2",
                minValue = 1,
                maxValue = 7,
                minText = "1",
                maxText = "7",
                valueStep = 1,
                default = 7,
                default1 = 7,
                default2 = 7,
                default3 = 7,
                default4 = 7,
                toolTip = "Selects which chat window HitsMode outputs to. \nThere can be up to 7 chat windows open at once. \nGeneral Chat is usually 1, and Combat Chat is usually 2. \nMove this slider until you find the one you want to use.",
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                text = "Message Threshold",
                type = "slider",
                var = "threshold2",
                minValue = 0,
                maxValue = 200,
                minText = "0",
                maxText = "200",
                valueStep = 1,
                default = 0,
                default1 = 0,
                default2 = 0,
                default3 = 0,
                default4 = 0,
                toolTip = "Lets you suppress messages with values below a certain threshold.\nFor example, setting this slider to 10 will suppress all messages that are 10 points or less.\nThe threshold functions as an absolute value, so the above example would\nsuppress messages between -10 and 10.",
        };
        i = i + 1;        
        HM_OptionsList[p][i] = { ---------------------------------------------------------------
                type = "heading",
                text = "Window 3 Options",
                toolTip = "These options are specific to chat window 3 only. \nThis is where you specify which WoW chat window to use for each HitsMode window. \n(More options are planned for future versions.)",
        };
        i = i + 1;        
        HM_OptionsList[p][i] = { 
                text = "Enable Chat Window 3",
                var = "enable3",
                hideColor = true,
                single = true,
                toolTip = "The master switch that turns on and off chat window 3.",
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                text = "Output to Chat Window",
                type = "slider",
                var = "window3",
                minValue = 1,
                maxValue = 7,
                minText = "1",
                maxText = "7",
                valueStep = 1,
                default = 7,
                default1 = 7,
                default2 = 7,
                default3 = 7,
                default4 = 7,
                toolTip = "Selects which chat window HitsMode outputs to. \nThere can be up to 7 chat windows open at once. \nGeneral Chat is usually 1, and Combat Chat is usually 2. \nMove this slider until you find the one you want to use.",
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                text = "Message Threshold",
                type = "slider",
                var = "threshold3",
                minValue = 0,
                maxValue = 200,
                minText = "0",
                maxText = "200",
                valueStep = 1,
                default = 0,
                default1 = 0,
                default2 = 0,
                default3 = 0,
                default4 = 0,
                toolTip = "Lets you suppress messages with values below a certain threshold.\nFor example, setting this slider to 10 will suppress all messages that are 10 points or less.\nThe threshold functions as an absolute value, so the above example would\nsuppress messages between -10 and 10.",
        };
        i = i + 1;        
        HM_OptionsList[p][i] = { ---------------------------------------------------------------
                type = "heading",
                text = "Window 4 Options",
                toolTip = "These options are specific to chat window 4 only. \nThis is where you specify which WoW chat window to use for each HitsMode window. \n(More options are planned for future versions.)",
        };
        i = i + 1;        
        HM_OptionsList[p][i] = { 
                text = "Enable Chat Window 4",
                var = "enable4",
                hideColor = true,
                single = true,
                toolTip = "The master switch that turns on and off chat window 4.",
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                text = "Output to Chat Window",
                type = "slider",
                var = "window4",
                minValue = 1,
                maxValue = 7,
                minText = "1",
                maxText = "7",
                valueStep = 1,
                default = 7,
                default1 = 7,
                default2 = 7,
                default3 = 7,
                default4 = 7,
                toolTip = "Selects which chat window HitsMode outputs to. \nThere can be up to 7 chat windows open at once. \nGeneral Chat is usually 1, and Combat Chat is usually 2. \nMove this slider until you find the one you want to use.",
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                text = "Message Threshold",
                type = "slider",
                var = "threshold4",
                minValue = 0,
                maxValue = 200,
                minText = "0",
                maxText = "200",
                valueStep = 1,
                default = 0,
                default1 = 0,
                default2 = 0,
                default3 = 0,
                default4 = 0,
                toolTip = "Lets you suppress messages with values below a certain threshold.\nFor example, setting this slider to 10 will suppress all messages that are 10 points or less.\nThe threshold functions as an absolute value, so the above example would\nsuppress messages between -10 and 10.",
        };
        i = i + 1;        
        
        
        
        
        ----------------------------------------------------------------------------------------
        ---- PANE 2: Messages ------------------------------------------------------------------
        ----------------------------------------------------------------------------------------
        p = p + 1;
        i = 1;
        
        HM_OptionsList[p][i] = { ---------------------------------------------------------------
                type = "heading",
                text = "Spell School Colors",
        };
        i = i + 1;
        
        HM_OptionsList[p][i] = {
                type =  "school",
                text = "Arcane Spell Damage",
                var = "Arcane",
                default1 = 1,
                defaultColor = { r = (175/255),  g = (175/255),  b = (175/255) },                -- White
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                type =  "school",
                text = "Fire Spell Damage",
                var = "Fire",
                default1 = 1,
                defaultColor = { r = (255/255),  g = (0/255),  b = (0/255) },                -- Red
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                type =  "school",
                text = "Frost Spell Damage",
                var = "Frost",
                default1 = 1,
                defaultColor = { r = (0/255),  g = (0/255),  b = (255/255) },                -- Blue
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                type =  "school",
                text = "Holy Spell Damage",
                var = "Holy",
                default1 = 1,
                defaultColor = { r = (255/255),  g = (128/255),  b = (128/255) },                -- Pink
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                type =  "school",
                text = "Nature Spell Damage",
                var = "Nature",
                default1 = 1,
                defaultColor = { r = (0/255),  g = (255/255),  b = (0/255) },                -- Green
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                type =  "school",
                text = "Shadow Spell Damage",
                var = "Shadow",
                default1 = 1,
                defaultColor = { r = (185/255),  g = (0/255),  b = (171/255) },                -- Shadow
        };
        i = i + 1;
        -------------------------------------------------------------------------
        
        HM_OptionsList[p][i] = { ---------------------------------------------------------------
                type = "heading",
                text = "Actions Taken By You",
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                text = "Absorb",
                var = "you_absorb",
                default1 = 1,
                defaultColor = { r = (  0/255),  g = (128/255),  b = (  0/255) },                -- Dark Green
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Block",
                var = "you_block",
                default1 = 1,
                defaultColor = { r = (  0/255),  g = (128/255),  b = (  0/255) },                -- Dark Green
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Blocked Amount",
                var = "you_blockedamount",
                default1 = 1,
                defaultColor = { r = (  0/255),  g = (128/255),  b = (  0/255) },                -- Dark Green
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Deflect",
                var = "you_deflect",
                default1 = 1,
                defaultColor = { r = (  0/255),  g = (128/255),  b = (  0/255) },                -- Dark Green
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                text = "Dispel",
                var = "you_purge",
                default1 = 1,
                defaultColor = { r = (  255/255),  g = (0/255),  b = (  0/255) },                -- Red
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Dodge",
                var = "you_dodge",
                default1 = 1,
                defaultColor = { r = (  0/255),  g = (128/255),  b = (  0/255) },                -- Dark Green
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Evade",
                var = "you_evade",
                default1 = 1,
                defaultColor = { r = (  0/255),  g = (128/255),  b = (  0/255) },                -- Dark Green
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Falling Damage",
                var = "you_fall",
                default1 = 1,
                defaultColor = { r = (255/255),  g = ( 47/255),  b = ( 47/255) },                -- Red
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Gain A Buff",
                var = "you_gain",
                default1 = 1,
                defaultColor = { r = (255/255),  g = (128/255),  b = (128/255) },                -- Pink
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Gain Experience",
                var = "exp",
                default1 = 1,
                defaultColor = { r = (111/255),  g = (111/255),  b = (255/255) },                -- Purple
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Gain Mana/Rage/Energy",
                var = "you_gainmana",
                default1 = 1,
                defaultColor = { r = (255/255),  g = (255/255),  b = (  0/255) },                -- Yellow
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                text = "Gain Extra Attacks",
                var = "you_gainatk",
                default1 = 1,
                defaultColor = { r = (255/255),  g = (255/255),  b = (  0/255) },                -- Yellow
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                text = "Heal Yourself (displays in addition to Instant Heal)",
                var = "you_healyourself",
                default1 = 0,
                defaultColor = { r = (255/255),  g = (255/255),  b = (  0/255) },                -- Yellow
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Immune",
                var = "you_immune",
                default1 = 1,
                defaultColor = { r = (  0/255),  g = (128/255),  b = (  0/255) },                -- Dark Green
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Instant Heal",
                var = "you_heal",
                default1 = 1,
                defaultColor = { r = (255/255),  g = (255/255),  b = (  0/255) },                -- Yellow
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                text = "Interrupt Spell",
                var = "you_inter",
                default1 = 1,
                defaultColor = { r = (255/255),  g = (255/255),  b = (  0/255) },                -- Yellow
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Instant Spell Damage",
                var = "you_nuke",
                default1 = 1,
                defaultColor = { r = (255/255),  g = (128/255),  b = (128/255) },                -- Pink
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Melee Damage",
                var = "you_melee",
                default1 = 1,
                defaultColor = { r = (  0/255),  g = (255/255),  b = ( 36/255) },                -- Green
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Miss",
                var = "you_miss",
                default1 = 1,
                defaultColor = { r = (  0/255),  g = (128/255),  b = (  0/255) },                -- Dark Green
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Parry",
                var = "you_parry",
                default1 = 1,
                defaultColor = { r = (  0/255),  g = (128/255),  b = (  0/255) },                -- Dark Green
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                text = "Drop Totem",
                var = "you_totem",
                default1 = 1,
                defaultColor = { r = (  0/255),  g = (128/255),  b = (  0/255) },                -- Dark Green
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Periodic Spell Damage",
                var = "you_dot",
                default1 = 1,
                defaultColor = { r = (255/255),  g = (128/255),  b = (128/255) },                -- Pink
        };
        i = i + 1;


        --------------




        
        
        ----------------
        
        
        HM_OptionsList[p][i] = { 
                text = "Resist",
                var = "you_resist",
                default1 = 1,
                defaultColor = { r = (  0/255),  g = (128/255),  b = (  0/255) },                -- Dark Green
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Spell Fades",
                var = "you_fades",
                default1 = 1,
                defaultColor = { r = (255/255),  g = (128/255),  b = (128/255) },                -- Pink
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "You Are Periodically Healed",
                var = "you_are_hot",
                default1 = 1,
                defaultColor = { r = (255/255),  g = (255/255),  b = (  0/255) },                -- Yellow
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "You Periodically Heal Others",
                var = "you_hot_others",
                default1 = 1,
                defaultColor = { r = (255/255),  g = (255/255),  b = (  0/255) },                -- Yellow
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                text = "You Are Afflicted By A Debuff",
                var = "you_afflicted",
                default1 = 1,
                defaultColor = { r = (255/255),  g = (255/255),  b = (  0/255) },                -- Yellow
        };
        i = i + 1;
        HM_OptionsList[p][i] = { ---------------------------------------------------------------
                type = "heading",
                text = "Actions Taken By Your Attacker",
        };
        i = i + 1;        
        HM_OptionsList[p][i] = { 
                text = "A Buff Is Removed",
                var = "mob_debuff",
                default1 = 1,
                defaultColor = { r = (255/255),  g = (128/255),  b = (128/255) },                -- Pink
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "You Slay An Enemy",
                var = "mob_died",
                default1 = 1,
                defaultColor = { r = (255/255),  g = (255/255),  b = (255/255) },                -- White
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                text = "An Enemy Dies (will display [Name] dies)",
                var = "mob_dies",
                default1 = 1,
                defaultColor = { r = (255/255),  g = (255/255),  b = (255/255) },                -- White
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                text = "Someone Else Killed Someone",
                var = "mob_died_3rd",
                default1 = 1,
                defaultColor = { r = (255/255),  g = (255/255),  b = (255/255) },                -- White
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                text = "Death Separator (DREADED ---- MESSAGE!)",
                var = "mob_died_sep",
                default1 = 1,
                defaultColor = { r = (255/255),  g = (255/255),  b = (255/255) },                -- White
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                text = "Absorb",
                var = "mob_absorb",
                default1 = 1,
                defaultColor = { r = (128/255),  g = (  0/255),  b = (  0/255) },                -- Dark Red
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Block",
                var = "mob_block",
                default1 = 1,
                hideColor = true,
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Deflect",
                var = "mob_deflect",
                default1 = 1,
                defaultColor = { r = (128/255),  g = (  0/255),  b = (  0/255) },                -- Dark Red
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Evade",
                var = "mob_evade",
                default1 = 1,
                defaultColor = { r = (128/255),  g = (  0/255),  b = (  0/255) },                -- Dark Red
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Dodge",
                var = "mob_dodge",
                default1 = 1,
                defaultColor = { r = (128/255),  g = (  0/255),  b = (  0/255) },                -- Dark Red
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Gains A Buff",
                var = "mob_gains",
                default1 = 1,
                defaultColor = { r = (255/255),  g = (128/255),  b = (128/255) },                -- Pink
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Immune",
                var = "mob_immune",
                default1 = 1,
                defaultColor = { r = (128/255),  g = (  0/255),  b = (  0/255) },                -- Dark Red
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Instant Spell Damage",
                var = "mob_nuke",
                default1 = 1,
                defaultColor = { r = (255/255),  g = (128/255),  b = (128/255) },                -- Pink
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                text = "Interruption",
                var = "mob_inter",
                default1 = 1,
                hideColor = true,
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Melee Damage",
                var = "mob_melee",
                default1 = 1,
                defaultColor = { r = (255/255),  g = ( 47/255),  b = ( 47/255) },                -- Red
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Miss",
                var = "mob_miss",
                default1 = 1,
                defaultColor = { r = (128/255),  g = (  0/255),  b = (  0/255) },                -- Dark Red
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Parry",
                var = "mob_parry",
                default1 = 1,
                defaultColor = { r = (128/255),  g = (  0/255),  b = (  0/255) },                -- Dark Red
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                text = "Periodic Spell Damage",
                var = "mob_dot",
                default1 = 1,
                defaultColor = { r = (255/255),  g = (128/255),  b = (128/255) },                -- Pink
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Resist",
                var = "mob_resist",
                default1 = 1,
                defaultColor = { r = (128/255),  g = (  0/255),  b = (  0/255) },                -- Dark Red
        };
        i = i + 1;
        HM_OptionsList[p][i] = { ---------------------------------------------------------------
                type = "heading",
                text = "Misc Actions",
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                text = "You Craft Something",
                var = "you_craft",
                default1 = 1,
                defaultColor = { r = (128/255),  g = (  0/255),  b = (  0/255) },                -- Dark Red
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                text = "You Enchant Something",
                var = "you_ench",
                default1 = 1,
                defaultColor = { r = (128/255),  g = (  0/255),  b = (  0/255) },                -- Dark Red
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                text = "You Loot Something",
                var = "you_loot",
                default1 = 1,
                defaultColor = { r = (0/255),  g = (  156/255),  b = (  0/255) },                -- Dark Red
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                text = "Someone Else Loots Something",
                var = "they_loot",
                default1 = 1,
                defaultColor = { r = (128/255),  g = (  0/255),  b = (  0/255) },                -- Dark Red
        };
        i = i + 1;
        HM_OptionsList[p][i] = { ---------------------------------------------------------------
                type = "heading",
                text = "Attacker Versus Your Pet",
        };
        i = i + 1;        
        HM_OptionsList[p][i] = { 
                text = "Block",
                var = "vspet_block",
                default1 = 1,
                defaultColor = { r = (128/255),  g = (  0/255),  b = (  0/255) },                -- Dark Red
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Blocked Amount",
                var = "vspet_blockedamount",
                default1 = 1,
                defaultColor = { r = (128/255),  g = (  0/255),  b = (  0/255) },                -- Dark Red
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Deflect",
                var = "vspet_deflect",
                default1 = 1,
                defaultColor = { r = (128/255),  g = (  0/255),  b = (  0/255) },                -- Dark Red
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Dodge",
                var = "vspet_dodge",
                default1 = 1,
                defaultColor = { r = (128/255),  g = (  0/255),  b = (  0/255) },                -- Dark Red
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Evade",
                var = "vspet_evade",
                default1 = 1,
                defaultColor = { r = (128/255),  g = (  0/255),  b = (  0/255) },                -- Dark Red
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Immune",
                var = "vspet_immune",
                default1 = 1,
                defaultColor = { r = (128/255),  g = (  0/255),  b = (  0/255) },                -- Dark Red
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Instant Spell Damage",
                var = "vspet_nuke",
                default1 = 1,
                defaultColor = { r = (255/255),  g = (128/255),  b = (128/255) },                -- Pink
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Melee Damage",
                var = "vspet_melee",
                default1 = 1,
                defaultColor = { r = (255/255),  g = ( 47/255),  b = ( 47/255) },                -- Red
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Parry",
                var = "vspet_parry",
                default1 = 1,
                defaultColor = { r = (128/255),  g = (  0/255),  b = (  0/255) },                -- Dark Red
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Periodic Spell Damage",
                var = "vspet_dot",
                default1 = 1,
                defaultColor = { r = (255/255),  g = (128/255),  b = (128/255) },                -- Pink
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Resist",
                var = "vspet_resist",
                default1 = 1,
                defaultColor = { r = (128/255),  g = (  0/255),  b = (  0/255) },                -- Dark Red
        };
        i = i + 1;
        HM_OptionsList[p][i] = { ---------------------------------------------------------------
                type = "heading",
                text = "Actions Taken By Your Pet",
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Instant Spell Damage",
                var = "pet_nuke",
                default1 = 1,
                defaultColor = { r = (255/255),  g = (128/255),  b = (128/255) },                -- Pink
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Melee Damage",
                var = "pet_melee",
                default1 = 1,
                defaultColor = { r = (  0/255),  g = (255/255),  b = ( 36/255) },                -- Green
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Miss",
                var = "pet_miss",
                default1 = 1,
                defaultColor = { r = (  0/255),  g = (128/255),  b = (  0/255) },                -- Dark Green
        };
        i = i + 1;
        HM_OptionsList[p][i] = { ---------------------------------------------------------------
                type = "heading",
                text = "Actions Taken By Others",
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Others Heal You",
                var = "others_heal_you",
                default1 = 1,
                defaultColor = { r = (255/255),  g = (255/255),  b = (  0/255) },                -- Yellow
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Others Periodically Heal You",
                var = "others_hot_you",
                default1 = 1,
                defaultColor = { r = (255/255),  g = (255/255),  b = (  0/255) },                -- Yellow
        };
        i = i + 1;
        HM_OptionsList[p][i] = { 
                text = "Spell Fades From Someone",
                var = "others_fade",
                defaultColor = { r = (255/255),  g = (128/255),  b = (128/255) },                -- Pink
        };
        i = i + 1;
        HM_OptionsList[p][i] = { ---------------------------------------------------------------
                type = "heading",
                text = "Other",
        };
        i = i + 1;
        HM_OptionsList[p][i] = {
                text = "Honor Gain",
                var = "you_gain_honor",
                defaultColor = { r = (255/255),  g = (255/255),  b = (0/255) },                -- Yellow
        };
        i = i + 1;



        ----------------------------------------------------------------------------------------
        ---- PANE 3: Presets -------------------------------------------------------------------
        ----------------------------------------------------------------------------------------
        --p = p + 1;
        --i = 1;
        --
        --HM_OptionsList[p][i] = {
                --type = "heading",
                --text = "Presets are not implemented yet.",
                --toolTip = "Presets are coming soon! HitsMode can be time consuming to configure. This screen will show a list of presets with buttons to click to load the preset. There are several presets planned which will cover several of the most popular ways to configure HitsMode.",
        --};
        --i = i + 1;
--
end
