--[[ HitsMode, by Allara ]]--


--
--  HitsMode User Interface Code and Graphics Copyright (C) 2005-2007 Jeremy Fuller (Allara)
--
--  Please do not use the code or graphics for the user interface without permission.
--  Contact me at allara.starmist@gmail.com for more information.
--


-- Globals
HM_NUMOPTIONS = 18;



-- The OnShow handler
function HM_OptionsFrameOnShow()
        HM_Disable();
        PlaySound("igMainMenuOpen");
        HM_OptionsVisible = 1;
        HM_UpdateOptions();
        HM_SetInfo(HITSMODE_OPTION_ONSHOW_INFO);
        getglobal("HMOptionsWindowHeaderText"):SetText("HitsMode v"..HM_Version);
end


-- The OnHide handler
function HM_OptionsFrameOnHide()
        PlaySound("igMainMenuClose");
        HM_OptionsVisible = 0;
        if (HM_GetValue("enable") == 1) then
                HM_Enable();
        end
        -- myAddOns support
        if(MYADDONS_ACTIVE_OPTIONSFRAME == HMOptions) then
                ShowUIPanel(myAddOnsFrame);
        end
end


-- Gets the number of options in the current panel
function HM_GetOptionCount()
        return table.getn(HM_OptionsList[HM_CurrentPanel]);
end


-- Gets the current offset
function HM_GetOffset()
        return FauxScrollFrame_GetOffset(HMOptionsPane);
end


-- Draws the option window
-- Important: the options system must be fully initialized before calling this
function HM_UpdateOptions()
        local c, cc;
        
        local panel = HM_CurrentPanel;
        local offset = HM_GetOffset();
        local numItems = HM_GetOptionCount();
        
        FauxScrollFrame_Update(HMOptionsPane, numItems, HM_NUMOPTIONS, 26);
        
        if (HM_DrawDataStarted == 0) then
                HM_DrawDataStarted = 1;
        else
                return;
        end
        
        for c = 1, HM_NUMOPTIONS do
                local prefix = "HMOptionLine"..c;
                local line = getglobal(prefix);
                local highlight = getglobal(prefix.."_HighlightBox");
                local headerHighlight = getglobal(prefix.."_HeaderHighlightBox");
                local description = getglobal(prefix.."_Description");
                local color = getglobal(prefix.."_Color");
                local swatch = getglobal(prefix.."_ColorSwatchTexture");
                local heading = getglobal(prefix.."_Heading");
                local slider = getglobal(prefix.."_Slider");
                local divider = getglobal(prefix.."_DividerLine");
                
                local config = HM_OptionsList[panel][c+offset];
                                
                -- An option exists
                if (config) then
                        line:Show();
                        HM_HideOptionsLine(c);
                        if (c == HM_NUMOPTIONS) then
                                divider:Hide();
                        end

                        -- HEADING
                        if (config.type == "heading") then
                                line.disableHighlight = 1;
                                heading:SetText(config.text);
                                heading:Show();
                                headerHighlight:Show();
                                
                        -- SLIDER
                        elseif (config.type == "slider") then
                                local string = getglobal(prefix.."_SliderText");
                                local low = getglobal(prefix.."_SliderLow");
                                local high = getglobal(prefix.."_SliderHigh");
                                local valuetext = getglobal(prefix.."_SliderValueText");
                                local getvalue = HM_GetValue(config.var);
                                slider:SetMinMaxValues(config.minValue, config.maxValue);
                                slider:SetValueStep(config.valueStep);
                                slider:SetValue(getvalue);
                                valuetext:SetText(getvalue);
                                description:SetText(config.text);
                                low:SetText(config.minText);
                                high:SetText(config.maxText);
                                description:Show();
                                slider:Show();
                                
                        -- REGULAR OPTION
                        elseif (config.type == "school") then
                                description:SetText(config.text);
                                description:Show();
                                if (config.hideColor == nil) then
                                        local col = HM_GetColor(config.var);
                                        color.r = col.r;
                                        color.g = col.g;
                                        color.b = col.b;
                                        swatch:SetTexture(col.r, col.g, col.b);
                                        color:Show();
                                end
                        else
                                for cc = 1, 4 do
                                        local checkbutton = getglobal("HMOptionLine"..c.."_CheckButton"..cc);
                                        checkbutton:SetChecked(HM_GetValue(config.var, cc));
                                        if (config.single == nil) then
                                                checkbutton:Show();
                                        elseif (cc == 4) then
                                                checkbutton:Show();
                                                checkbutton:SetChecked(HM_GetValue(config.var));
                                        end
                                end
                                description:SetText(config.text);
                                description:Show();
                                line.disableHighlight = nil;
                                if (config.hideColor == nil) then
                                        local col = HM_GetColor(config.var);
                                        color.r = col.r;
                                        color.g = col.g;
                                        color.b = col.b;
                                        swatch:SetTexture(col.r, col.g, col.b);
                                        color:Show();
                                end                                
                                
                        end

                -- No option exists
                else
                        line:Hide();
                end
        end
        
        HM_DrawDataStarted = 0;
end


function HM_HideOptionsLine(c)
        local cc;
        local prefix = "HMOptionLine"..c;
        local line = getglobal(prefix);
        local highlight = getglobal(prefix.."_HighlightBox");
        local headerHighlight = getglobal(prefix.."_HeaderHighlightBox");
        local description = getglobal(prefix.."_Description");
        local color = getglobal(prefix.."_Color");
        local heading = getglobal(prefix.."_Heading");
        local slider = getglobal(prefix.."_Slider");

        for cc = 1, 4 do
                local checkbutton = getglobal("HMOptionLine"..c.."_CheckButton"..cc);
                checkbutton:Hide();
        end
        description:Hide();
        color:Hide();
        highlight:Hide();
        heading:Hide();
        slider:Hide();
        headerHighlight:Hide();
        line.disableHighlight = nil;
end


function HM_SwitchPanel(panel)
        HM_CurrentPanel = panel;
        FauxScrollFrame_SetOffset(HMOptionsPane, 0);
        
        local i;
        for i = 1, HM_NUMTABS do
                local tab = getglobal("HMOptionsPaneBgFrameTab"..i);
                if (i == panel) then
                        tab:SetFrameLevel(HMOptionsPaneBgFrame:GetFrameLevel() + 1);
                else
                        tab:SetFrameLevel(HMOptionsPaneBgFrame:GetFrameLevel());
                end
        end

        PanelTemplates_SetTab(HMOptionsPaneBgFrame, panel);
        HM_UpdateOptions();
end


function HM_SetInfo(str)
        if (string == "" or string == nil) then
                GameTooltip:Hide();
        else
                GameTooltip:SetOwner(UIParent, "ANCHOR_BOTTOMRIGHT");
                GameTooltip:SetText(str);
                GameTooltip:Show();
        end
end


function HM_Option_OnMouseEnter(o)
        if (o:GetName() == "HMResetButton") then
                HM_SetInfo(HITSMODE_OPTION_LOADDEFAULTS_INFO);
        elseif (o:GetName() == "HMSaveGlobalButton") then
                HM_SetInfo(HITSMODE_OPTION_SAVEGLOBAL_INFO);
        elseif (o:GetName() == "HMLoadGlobalButton") then
                local text = HITSMODE_OPTION_LOADGLOBAL_INFO;
                if (HM_Options["global"] == nil) then
                        text = text..HITSMODE_OPTION_LOADGLOBAL_GLOBALNOTPRESENT_INFO;
                end
                HM_SetInfo(text);
        elseif (o:GetName() == "HMColorPickerOkayButton" or o:GetName() == "HMColorPickerCancelButton") then
                -- do nothing
        elseif (string.match(o:GetName(), "Tab")) then
                HM_SetInfo(getglobal("HITSMODE_OPTION_TAB"..o:GetID().."_INFO"));
        else
                if (getglobal(o:GetName()).disableHighlight == nil) then
                        if (getglobal(o:GetName().."_HighlightBox") ~= nil) then
                                getglobal(o:GetName().."_HighlightBox"):Show();
                        end
                end
                local offset = tonumber(o:GetID());
                local option = HM_OptionsList[HM_CurrentPanel][HM_GetOffset()+offset];
                if (option) then
                        if (option.toolTip) then
                                HM_SetInfo(option.toolTip);
                        else
                                HM_SetInfo("");
                        end
                else
                        HM_SetInfo("");
                end
        end
end


function HM_Option_OnMouseLeave(o)
        if (getglobal(o:GetName().."_HighlightBox")) then
                if (getglobal(o:GetName()).disableHighlight == nil) then
                        getglobal(o:GetName().."_HighlightBox"):Hide();
                end
        end
        HM_SetInfo("");
end


function HM_Option_SliderOnValueChanged(o)
        local slider = getglobal(o:GetName().."_Slider");
        local offset = tonumber(o:GetID());
        local option = HM_OptionsList[HM_CurrentPanel][HM_GetOffset()+offset];
        HM_SetAllValues(option.var, slider:GetValue());
end


function HM_Option_CheckboxOnClick(o)
        local offset = tonumber(o:GetParent():GetID());
        local option = HM_OptionsList[HM_CurrentPanel][HM_GetOffset()+offset];
        local checked;
        if (o:GetChecked()) then
                checked = 1;
        else
                checked = 0;
        end
        HM_SetValue(option.var, checked, tonumber(o:GetID()));
        if (option.single) then
                HM_SetAllValues(option.var, checked);
        end
end


function HM_OpenColorPicker(o)
        CloseMenus();
        local offset = tonumber(o:GetID());
        local option = HM_OptionsList[HM_CurrentPanel][HM_GetOffset()+offset];
        local prefix = "HMOptionLine"..HM_CurrentColor;
        local swatch = getglobal(prefix.."_ColorSwatchTexture");
        local color = getglobal(prefix.."_Color");
        local colorTable = HM_GetColor(option.var);
        color.r = colorTable.r;
        color.g = colorTable.g;
        color.b = colorTable.b;
        HMColorPicker:SetColorRGB(color.r, color.g, color.b);
        HMColorPicker.previousValues = { r = color.r, g = color.g, b = color.b };
        HMColorPicker:Show();
end


function HM_Options_ColorFunc()
        local r, g, b = HMColorPicker:GetColorRGB();
        local offset = tonumber(HM_CurrentColor);
        local option = HM_OptionsList[HM_CurrentPanel][HM_GetOffset()+offset];
        local prefix = "HMOptionLine"..HM_CurrentColor;
        local swatch = getglobal(prefix.."_ColorSwatchTexture");
        local color = getglobal(prefix.."_Color");
        local savedColor = { };
        
        swatch:SetTexture(r, g, b);
        color.r = r;
        color.g = g;
        color.b = b;
        HMColorPicker_ValueR:SetText("R: "..(r*255));
        HMColorPicker_ValueG:SetText("G: "..(g*255));
        HMColorPicker_ValueB:SetText("B: "..(b*255));
        savedColor.r = r;
        savedColor.g = g;
        savedColor.b = b;
        HM_SetColor(option.var, savedColor);
end


function HM_Options_CancelFunc()
        local offset = tonumber(HM_CurrentColor);
        local option = HM_OptionsList[HM_CurrentPanel][HM_GetOffset()+offset];
        local prefix = "HMOptionLine"..HM_CurrentColor;
        local swatch = getglobal(prefix.."_ColorSwatchTexture");
        
        swatch:SetTexture(HMColorPicker.previousValues.r, HMColorPicker.previousValues.g, HMColorPicker.previousValues.b);
        HM_SetColor(option.var, HMColorPicker.previousValues);
end
