--[[ HitsMode, by Allara ]]--


-- This is the main output function. It takes all the discrete data points that have been parsed
-- and combines them, according to all the options, into the desired chat line. Here is a
-- description of the arguments:
--
--   OriginatingUnit
--     [Required] The entity that performed the action. Plain text.
--   TargetUnit
--     [Optional] The entity that the action is being performed on. Plain text.
--   SpecialAttack
--     [Optional] The name of the skill being used.
--   VerboseMessage
--     [Required] The name of the message to display (i.e. blocked, hit for). This is a lookup to
--     the localization table accessed by HM_GetString.
--   Option
--     [Required] The "var" of the option that applies to this message. This controls whether the
--     message is displayed and in what color.
--   Message
--     [Optional] Should be named "Damage". This is the amount of damage, health, etc. that the
--     action did.
--   ChatMessage
--     [Unused] The actual chat message that was parsed. (For future expansion.)
--   ChatEvent
--     [Unused] The actual chat event that was triggered. (For future expansion.)


-- This function is a wrapper for the actual renderer, used to create multiwindow support
function HM_Output(a, b, c, d, e, f, g, h, i)
        local count;
        
        for count = 1, 4 do
                if (HM_GetValue("enable"..count) == 1) then
                        HM_CoerceChat_CurrentWindow = count;
                        HM_CoerceChat = 1;
                        HM_Output_Multiwindow(a, b, c, d, e, f, g, h, i);
                        HM_CoerceChat = 0;
                end
        end
end


function HM_OutputConfiguredString(option, message)
        local count;
        
        for count = 1, 4 do
                if (HM_GetValue("enable"..count) == 1) then
                        HM_CoerceChat_CurrentWindow = count;
                        HM_CoerceChat = 1;
                        if (HM_GetValue(option) == 1) then
                                HM_HMPrint(HM_GCC(option)..HM_GetString(message));
                        end
                        HM_CoerceChat = 0;
                end
        end
end


-- The actual renderer: it doesn't have any idea what multiwindow support is =)
function HM_Output_Multiwindow(OriginatingUnit, TargetUnit, SpecialAttack, VerboseMessage, Option, Message, Crit, ChatMessage, ChatEvent)

        local OriginatingUnitType, TargetUnitType, ShortText, ForText, s, ColorTag, sType, lul, eVa, dNum, eVand, eVan;
        local OriginatingUnit_Text, TargetUnit_Text, SpecialAttack_Text, VerboseMessage_Text, Message_Text;
        eVand = "";
        sTypee = "";
        
        -- If we're not supposed to display this message, then exit
        if (HM_GetValue(Option) ~= 1) then return; end
        
        -- Suppress the message if it's under the threshold
        local threshold = HM_GetValue("threshold"..HM_CoerceChat_CurrentWindow);
        if (threshold ~= 0 and Message ~= nil and math.abs(Message) <= threshold) then return; end
        
        -- This bit guards against some nil comparisons
        if (OriginatingUnit == nil) then
                OriginatingUnit_Text = "";
                OriginatingUnit = "";
        end
        if (TargetUnit == nil) then
                TargetUnit_Text = "";
                TargetUnit = "";
        end
        if (SpecialAttack == nil) then
                SpecialAttack_Text = "";
                SpecialAttack = "";
        end
        
        -- Sometimes the parser sends us "you" instead of "You"... fix that
        if (OriginatingUnit == "you") then OriginatingUnit = "You"; end
        if (TargetUnit == "you") then TargetUnit = "You"; end
        
        -- Process the unit names and figure out what type they are
        if (string.upper(OriginatingUnit) == "YOU") then
                OriginatingUnitType = "you";
        elseif (HM_IsPet(OriginatingUnit)) then
                OriginatingUnitType = "pet";
        else
                OriginatingUnitType = "mob";
        end
        if (string.upper(TargetUnit) == "YOU") then
                TargetUnitType = "you";
        elseif (HM_IsPet(TargetUnit)) then
                TargetUnitType = "pet";
        else
                TargetUnitType = "mob";
        end
        
        if (VerboseMessage == nil) then
                VerboseMessage_Text = "";
        else
                VerboseMessage_Text = HM_GetString(VerboseMessage);
        end
        
        if (Message ~= nil) then
                -- NOTE: ADD RESISTED VALUES TO SPELLMSG
                for dNum, sType, lul, eVan, eVa in string.gmatch(Message, "(%d+) ([%a]*) (%a*)(%s*)([%a%s%d%(%)%+%%]*)") do
                        Message = dNum;

                        if (HM_GetValue("schoCol") == 1 and Message ~= nil and sType ~= nil and sType ~= "Physical" and sType ~= "vulnerability" and sType ~= "Energy") then
                                --Message = HM_GCC(sType)..Message.."|r";
                                sTypee = sType;
                        elseif (eVa == "(glacing)" or eVa == "glancing") then
                                Message = Message;
                        else
                                sTypee = Option;
                        end
                        
                        if (HM_GetValue("extval") == 1 and Message ~= nil and eVa ~= nil) then
                                eVand = " "..HM_GCC("extval")..eVa.."|r";
                        end
                end


                -- HEALS AND STUFFZ

                        if (HM_IsPet(OriginatingUnit) and HM_GetValue("flagpet") == 1) then
                                        Message = "~"..Message.."~";
                        elseif (strfind(Option, "heal") or strfind(Option, "hot")) then
                                if (HM_GetValue("flagheals") == 1) then
                                        Message = "+"..Message;
                                end
                        end

                        -- CRITS COLOURING
                        if (sTypee == "") then
                                sTypee = Option;
                        end
                        if (Crit == 1) then
                                if (HM_GetValue("flagcrits") == 1) then
                                        Message = string.format("%s*|r%s%s|r%s*|r", HM_GCC("flagcrits"), HM_GCCO(sTypee, OriginatingUnitType, "crit"), Message, HM_GCC("flagcrits"));
                                else
                                        Message = string.format("%s%s|r", HM_GCCO(sTypee, OriginatingUnitType, "crit"), Message);
                        end
                        else
                                Message = HM_GCCO(sTypee, OriginatingUnitType, "not")..Message.."|r";
                        end

                        -- EXTRA VALUES
                
                
                Message_Text = Message..eVand;

        else
                Message_Text = VerboseMessage_Text;
        end


        
        
        -- If Message is nil, that means we probably blocked, parried, etc.
        -- So we make Message equal VerboseMessage. The output code checks this and usually
        -- won't display Message_Text if it equals VerboseMessage.
--        if (Message == nil) then
  --              Message_Text = VerboseMessage_Text;
    --    else
      --          Message_Text = Message;
        --end
        
        -- Flag Message for Pets or Heals (no colorization yet)


        
        -- Colorize SpecialAttack if it exists
        if (SpecialAttack ~= nil and SpecialAttack ~= "") then
                SpecialAttack_Text = HM_GCC("showskill")..SpecialAttack.."|r";
        else
                SpecialAttack_Text = "";
        end
        
        -- Colorize Message and make it a Crit if necessary

        
        -- Colorize Unit Names
        if (OriginatingUnitType == "you") then
                OriginatingUnit_Text = string.format("%s%s%s|r%s", HM_BracketLeft(), HM_GCC("showyou"), OriginatingUnit, HM_BracketRight());
        elseif (OriginatingUnitType == "pet") then
                OriginatingUnit_Text = string.format("%s%s%s|r%s", HM_BracketLeft(), HM_GCC("showpet"), OriginatingUnit, HM_BracketRight());
        else
                OriginatingUnit_Text = string.format("%s%s%s|r%s", HM_BracketLeft(), HM_GCC("showmob"), OriginatingUnit, HM_BracketRight());
        end
        if (TargetUnitType == "you") then
                TargetUnit_Text = string.format("%s%s%s|r%s", HM_BracketLeft(), HM_GCC("showyou"), TargetUnit, HM_BracketRight());
        elseif (TargetUnitType == "pet") then
                TargetUnit_Text = string.format("%s%s%s|r%s", HM_BracketLeft(), HM_GCC("showpet"), TargetUnit, HM_BracketRight());
        else
                TargetUnit_Text = string.format("%s%s%s|r%s", HM_BracketLeft(), HM_GCC("showmob"), TargetUnit, HM_BracketRight());
        end
        
        -- Construct a short version of VerboseMessage for Short Mode and for Verbose Mode B to use
        -- (Removes trailing " for")
        if (strsub(VerboseMessage_Text, -4, -1) == " for") then
                ShortText = strsub(VerboseMessage_Text, 1, -5);
        else
                ShortText = VerboseMessage_Text;
        end
        
        -- Verbose Mode B needs a constant for the word "for"
        ForText = HM_GetString("FOR");

        -- Colorize VerboseMessage, ShortText, and ForText
        if (HM_GetValue("verbosea") == 1) then
                ColorTag = HM_GCC("verbosea");
        elseif (HM_GetValue("verboseb") == 1) then
                ColorTag = HM_GCC("verboseb");
        else
                ColorTag = HM_BCC(1, 1, 1);
        end
        VerboseMessage_Text = ColorTag..VerboseMessage_Text.."|r";
        ShortText = ColorTag..ShortText.."|r";
        ForText = ColorTag..ForText.."|r";



        ------
        --- Main output section
        ------
        
        -------- DEBUG MODE
        if (HM_GetValue("debug") == 1) then
                s = string.format("%s %s %s %s", OriginatingUnit_Text, TargetUnit_Text, HM_BCC(1,0,0)..SpecialAttack_Text.."|r", VerboseMessage_Text, Message_Text);
                if (Message ~= VerboseText) then
                        s = string.format("%s %s", s, Message_Text);
                end
                
        -------- VERBOSE MODE A
        elseif (HM_GetValue("verbosea") == 1) then
                
                s = "";

                -- Unit name
                if        (OriginatingUnitType == "you" and HM_GetValue("showyou") == 1) or
                                (OriginatingUnitType == "pet" and HM_GetValue("showpet") == 1) or
                                (OriginatingUnitType == "mob" and HM_GetValue("showmob") == 1) then
                        s = s..OriginatingUnit_Text.." ";
                end
                
                -- Special case for "gains" message: display "gains" first
                if (VerboseMessage == "GAIN" or VerboseMessage == "GAINS") then
                        s = s..VerboseMessage_Text.." ";
                end
                
                -- Skill name
                if (SpecialAttack ~= nil and SpecialAttack ~= "" and HM_GetValue("showskill") == 1) then
                        s = s..SpecialAttack_Text.." ";
                end
                
                -- Verbose text (check for short mode)
                if (VerboseMessage ~= "GAIN" and VerboseMessage ~= "GAINS") then
                        if (HM_GetValue("shortmode") == 1) then
                                s = s..ShortText;
                        else
                                s = s..VerboseMessage_Text;
                        end
                end

                -- Message
                if (Message ~= VerboseText) then
                        s = s.." "..Message_Text;
                end
                
        
        -------- VERBOSE MODE B
        elseif (HM_GetValue("verboseb") == 1) then

                s = "";
                
                -- CASE 1: You or your pet did something to it
                if ((OriginatingUnitType == "you" or OriginatingUnitType == "pet") and TargetUnit ~= "") then

                        -- OriginatingUnit name
                        if        (OriginatingUnitType == "you" and HM_GetValue("showyou") == 1) or
                                        (OriginatingUnitType == "pet" and HM_GetValue("showpet") == 1) then
                                s = s..OriginatingUnit_Text.." ";
                        end
                        -- Special case for "gains" message: display "gains" first
                        if (VerboseMessage == "GAIN" or VerboseMessage == "GAINS") then
                                s = s..VerboseMessage_Text.." ";
                        end
                        -- Skill name
                        if (SpecialAttack ~= nil and SpecialAttack ~= "" and HM_GetValue("showskill") == 1) then
                                s = s..SpecialAttack_Text.." ";
                        end
                        -- ShortText goes here
                        if (VerboseMessage ~= "GAIN" and VerboseMessage ~= "GAINS") then
                                s = s..ShortText.." ";
                        end
                        -- TargetUnit name
                        if (HM_GetValue("showmob") == 1) then
                                s = s..TargetUnit_Text.." ";
                        end
                        if (Message ~= VerboseText) then
                                -- "for", unless Short Mode is on
                                if (HM_GetValue("shortmode") ~= 1) then
                                        s = s..ForText.." ";
                                end
                                -- Message
                                s = s..Message_Text;
                        end
                        
                -- CASE 2: It did something to you or your pet
                elseif (TargetUnit ~= "") then
                
                        -- Unit name
                        if        (OriginatingUnitType == "you" and HM_GetValue("showyou") == 1) or
                                        (OriginatingUnitType == "pet" and HM_GetValue("showpet") == 1) or
                                        (OriginatingUnitType == "mob" and HM_GetValue("showmob") == 1) then
                                s = s..OriginatingUnit_Text.." ";
                        end        
                        -- Special case for "gains" message: display "gains" first
                        if (VerboseMessage == "GAIN" or VerboseMessage == "GAINS") then
                                s = s..VerboseMessage_Text.." ";
                        end
                        -- Skill name
                        if (SpecialAttack ~= nil and SpecialAttack ~= "" and HM_GetValue("showskill") == 1) then
                                s = s..SpecialAttack_Text.." ";
                        end
                        -- ShortText goes here
                        if (VerboseMessage ~= "GAIN" and VerboseMessage ~= "GAINS") then
                                s = s..ShortText.." ";
                        end
                        -- TargetUnit name
                        if        (TargetUnitType == "you" and HM_GetValue("showyou") == 1) or
                                        (TargetUnitType == "pet" and HM_GetValue("showpet") == 1) or
                                        (TargetUnitType == "mob" and HM_GetValue("showmob") == 1) then
                                -- Don't put the target unit if verbose=message (like dodge, parry)
                                if (Message ~= VerboseText) then
                                        s = s..TargetUnit_Text.." ";
                                end
                        end
                        if (Message ~= VerboseText) then
                                -- "for", unless Short Mode is on
                                if (HM_GetValue("shortmode") ~= 1) then
                                        s = s..ForText.." ";
                                end
                                -- Message
                                s = s..Message_Text;
                        end

                -- DEFAULT CASE: Something happened without two targets specified
                -- We revert to Verbose Mode A in this case
                else
                        
                        -- Unit name
                        if        (OriginatingUnitType == "you" and HM_GetValue("showyou") == 1) or
                                        (OriginatingUnitType == "pet" and HM_GetValue("showpet") == 1) or
                                        (OriginatingUnitType == "mob" and HM_GetValue("showmob") == 1) then
                                s = s..OriginatingUnit_Text.." ";
                        end
                        -- Special case for "gains" message: display "gains" first
                        if (VerboseMessage == "GAIN" or VerboseMessage == "GAINS") then
                                s = s..VerboseMessage_Text.." ";
                        end
                        -- Skill name
                        if (SpecialAttack ~= nil and SpecialAttack ~= "" and HM_GetValue("showskill") == 1) then
                                s = s..SpecialAttack_Text.." ";
                        end
                        -- Verbose text (check for short mode)
                        if (VerboseMessage ~= "GAIN" and VerboseMessage ~= "GAINS") then
                                if (HM_GetValue("shortmode") == 1) then
                                        s = s..ShortText;
                                else
                                        s = s..VerboseMessage_Text;
                                end
                        end
                        -- Message
                        if (Message ~= VerboseText) then
                                s = s.." "..Message_Text;
                        end
                end

        -------- VERBOSE MODE C
        elseif (HM_GetValue("verbosec") == 1) then

                -- The message comes first followed by the divider
                local VerboseC_Text = Message_Text..HM_GCC("verbosec")..HM_GetString("CDIVIDER").."|r";
                
                s = "";
                
                -- CASE 1: You or your pet did something to it
                if ((OriginatingUnitType == "you" or OriginatingUnitType == "pet") and TargetUnit ~= "") then

                        -- OriginatingUnit name
                        if        (OriginatingUnitType == "you" and HM_GetValue("showyou") == 1) or
                                        (OriginatingUnitType == "pet" and HM_GetValue("showpet") == 1) then
                                s = s..OriginatingUnit_Text.." ";
                        end
                        -- Special case for "gains" message: display "gains" first
                        if (VerboseMessage == "GAIN" or VerboseMessage == "GAINS") then
                                s = s..VerboseMessage_Text.." ";
                        end
                        -- Skill name
                        if (SpecialAttack ~= nil and SpecialAttack ~= "" and HM_GetValue("showskill") == 1) then
                                s = s..SpecialAttack_Text.." ";
                        end
                        -- ShortText goes here
                        if (VerboseMessage ~= "GAIN" and VerboseMessage ~= "GAINS") then
                                s = s..ShortText.." ";
                        end
                        -- TargetUnit name
                        if (HM_GetValue("showmob") == 1) then
                                s = s..TargetUnit_Text.." ";
                        end
                        
                -- CASE 2: It did something to you or your pet
                elseif (TargetUnit ~= "") then
                
                        -- Unit name
                        if        (OriginatingUnitType == "you" and HM_GetValue("showyou") == 1) or
                                        (OriginatingUnitType == "pet" and HM_GetValue("showpet") == 1) or
                                        (OriginatingUnitType == "mob" and HM_GetValue("showmob") == 1) then
                                s = s..OriginatingUnit_Text.." ";
                        end        
                        -- Special case for "gains" message: display "gains" first
                        if (VerboseMessage == "GAIN" or VerboseMessage == "GAINS") then
                                s = s..VerboseMessage_Text.." ";
                        end
                        -- Skill name
                        if (SpecialAttack ~= nil and SpecialAttack ~= "" and HM_GetValue("showskill") == 1) then
                                s = s..SpecialAttack_Text.." ";
                        end
                        -- ShortText goes here
                        if (VerboseMessage ~= "GAIN" and VerboseMessage ~= "GAINS") then
                                s = s..ShortText.." ";
                        end
                        -- TargetUnit name
                        if        (TargetUnitType == "you" and HM_GetValue("showyou") == 1) or
                                        (TargetUnitType == "pet" and HM_GetValue("showpet") == 1) or
                                        (TargetUnitType == "mob" and HM_GetValue("showmob") == 1) then
                                -- Don't put the target unit if verbose=message (like dodge, parry)
                                if (Message ~= VerboseText) then
                                        s = s..TargetUnit_Text.." ";
                                end
                        end

                -- DEFAULT CASE: Something happened without two targets specified
                -- We revert to Verbose Mode A in this case
                else
                        
                        -- Unit name
                        if        (OriginatingUnitType == "you" and HM_GetValue("showyou") == 1) or
                                        (OriginatingUnitType == "pet" and HM_GetValue("showpet") == 1) or
                                        (OriginatingUnitType == "mob" and HM_GetValue("showmob") == 1) then
                                s = s..OriginatingUnit_Text.." ";
                        end
                        -- Special case for "gains" message: display "gains" first
                        if (VerboseMessage == "GAIN" or VerboseMessage == "GAINS") then
                                s = s..VerboseMessage_Text.." ";
                        end
                        -- Skill name
                        if (SpecialAttack ~= nil and SpecialAttack ~= "" and HM_GetValue("showskill") == 1) then
                                s = s..SpecialAttack_Text.." ";
                        end
                        -- Verbose text (check for short mode)
                        if (VerboseMessage ~= "GAIN" and VerboseMessage ~= "GAINS") then
                                if (HM_GetValue("shortmode") == 1) then
                                        s = s..ShortText;
                                else
                                        s = s..VerboseMessage_Text;
                                end
                        end
                end
                
                s = VerboseC_Text..s;
        
        -------- NO VERBOSE MODE
        else
                s = Message_Text;
        end
        
        -- And..... output the text
        HM_HMPrint(s);
end
